Utilities
*********

This section shows general objects and helper functions that are used with this package.


Battery Discharge Characteristics
=================================

.. autoclass:: balderhub.battery.lib.utils.battery_discharge_characteristic.BaseBatteryDischargeCharacteristic
    :members:

.. autoclass:: balderhub.battery.lib.utils.battery_discharge_characteristic.BaseDiscreteBatteryDischargeCharacteristic
    :members:
